pub struct DeserializeOptions {
    pub csv_without_headers: bool,
    pub csv_headers_as_keys: bool,
    pub csv_delimiter: Option<u8>,
    pub text_split_pattern: Option<Regex>,
}
Options for the Deserializer. The options are context specific and may only be honored when deserializing from a certain Encoding.

Fields

csv_without_headers: bool

Indicates that an input CSV does not include a header line. If false, the first line is discarded.

csv_headers_as_keys: bool

Indicates that the header fields of an input CSV should be used as keys for each row’s columns. This means that the deserialized row data will be of type object. Otherwise row data will be of type array.

csv_delimiter: Option<u8>

Optional custom delimiter for CSV input.

text_split_pattern: Option<Regex>

Optional regex pattern to split text input at.

Implementations

Creates new DeserializeOptions.