pub struct Deserializer<R> { /* private fields */ }
A Deserializer can deserialize input data from a reader into a Value.

Implementations

Creates a new Deserializer for reader with default options.

Creates a new Deserializer for reader with options.

Reads input data from the given reader and deserializes it in a Value.

Example
use dts_core::{de::DeserializerBuilder, Encoding};
use serde_json::json;
let buf = r#"["foo"]"#.as_bytes();

let mut de = DeserializerBuilder::new().build(buf);
let value = de.deserialize(Encoding::Json)?;

assert_eq!(value, json!(["foo"]));