Struct dts_core::de::DeserializerBuilder
source · [−]pub struct DeserializerBuilder { /* private fields */ }Expand description
A DeserializerBuilder can be used to build a Deserializer with certain
DeserializeOptions.
Example
use dts_core::{de::DeserializerBuilder, Encoding};
let buf = r#"["foo"]"#.as_bytes();
let deserializer = DeserializerBuilder::new()
.csv_delimiter(b'\t')
.build(buf);Implementations
sourceimpl DeserializerBuilder
impl DeserializerBuilder
sourcepub fn csv_without_headers(&mut self, yes: bool) -> &mut Self
pub fn csv_without_headers(&mut self, yes: bool) -> &mut Self
Indicates that an input CSV does not include a header line. If false, the first line is
discarded.
sourcepub fn csv_headers_as_keys(&mut self, yes: bool) -> &mut Self
pub fn csv_headers_as_keys(&mut self, yes: bool) -> &mut Self
Indicates that the header fields of an input CSV should be used as keys for each row’s columns. This means that the deserialized row data will be of type object. Otherwise row data will be of type array.
sourcepub fn csv_delimiter(&mut self, delim: u8) -> &mut Self
pub fn csv_delimiter(&mut self, delim: u8) -> &mut Self
Sets a custom CSV delimiter.
sourcepub fn text_split_pattern(&mut self, pattern: Regex) -> &mut Self
pub fn text_split_pattern(&mut self, pattern: Regex) -> &mut Self
Sets regex pattern to split text at.
sourcepub fn build<R>(&self, reader: R) -> Deserializer<R> where
R: Read,
pub fn build<R>(&self, reader: R) -> Deserializer<R> where
R: Read,
Builds the Deserializer for the given reader.