#[non_exhaustive]
pub enum Encoding {
    Json,
    Yaml,
    Toml,
    Json5,
    Csv,
    QueryString,
    Xml,
    Text,
    Gron,
    Hcl,
}
Encodings supported by this crate.

Not all of the supported encodings are supported to serialize and deserialize into. Some, like hjson only allow deserialization of encoded data but are not able to serialize back into the original representation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Json

JavaScript Object Notation

Yaml

Yet Another Markup Language

Toml

TOML configuration format

Json5

ES5 JSON

Csv

Comma separated values

QueryString

URL query string

Xml

Extensible Markup Language

Text

Plaintext document

Gron

Gron

Hcl

HCL

Implementations

Creates an Encoding from a path by looking at the file extension.

Returns None if the extension is absent or if the extension does not match any of the supported encodings.

Tries to detect the Encoding by looking at the first line of the input.

Returns None if the encoding cannot be detected from the first line.

Returns the name of the Encoding.