pub enum Source {
    Stdin,
    Path(PathBuf),
    Url(Url),
}
A source for data that needs to be deserialized.

Variants

Stdin

Stdin source.

Path(PathBuf)

Local file or directory source.

Url(Url)

Remote URL source.

Implementations

Returns Some if the source is a local path, None otherwise.

Returns true if the Source is a local path and the path exists on disk and is pointing at a directory.

Tries to detect the encoding of the source. Returns None if the encoding cannot be detected.

If source is a local path, this returns sources for all files matching the glob pattern.

Errors

Returns an error if the sink is not of variant Sink::Path, the pattern is invalid or if there is a io::Error while reading the file system.

Returns a SourceReader to read from the source.

Errors

May return an error if the source is Source::Path and the file cannot be opened of if source is Source::Url and there is an error requesting the remote url.