pub struct Serializer<W> { /* private fields */ }
A Serializer can serialize a Value into an encoded byte stream.

Implementations

Creates a new Serializer for writer with default options.

Creates a new Serializer for writer with options.

Serializes the given Value and writes the encoded data to the writer.

Example
use dts_core::{ser::SerializerBuilder, Encoding};
use serde_json::json;
let mut buf = Vec::new();
let mut ser = SerializerBuilder::new().compact(true).build(&mut buf);
ser.serialize(Encoding::Json, json!(["foo"]))?;

assert_eq!(&buf, r#"["foo"]"#.as_bytes());