pub struct SerializerBuilder { /* private fields */ }
A SerializerBuilder can be used to build a Serializer with certain SerializeOptions.

Example

use dts_core::{ser::SerializerBuilder, Encoding};

let writer = std::io::stdout();
let mut serializer = SerializerBuilder::new()
    .newline(true)
    .build(writer);

Implementations

Creates a new SerializerBuilder.

Emit output data in a compact format. This will disable pretty printing for encodings that support it.

Append a trailing newline to the serialized data.

When the input is an array of objects and the output encoding is CSV, the field names of the first object will be used as CSV headers. Field values of all following objects will be matched to the right CSV column based on their key. Missing fields produce empty columns while excess fields are ignored.

Sets a custom CSV delimiter.

Sets a custom separator to join text output with.

Builds the Serializer for the given writer.