pub struct SourceReader { /* private fields */ }
A type that can read from a Source. It is able to detect the Source’s encoding by looking at the first line of the input.

Implementations

Creates a new SourceReader for an io::Read implementation and an optional encoding hint.

Reads the first line from reader upon creation.

Errors

Returns an error if reading the first line from the reader fails.

Tries to detect the encoding of the source. If the source provides an encoding hint it is returned as is. Otherwise the SourceReader attempts to detect the encoding based on the contents of the first line of the input data.

Returns None if the encoding cannot be detected.