#[non_exhaustive]
pub enum Encoding {
Json,
Yaml,
Toml,
Json5,
Csv,
QueryString,
Xml,
Text,
Gron,
Hcl,
}Expand description
Encodings supported by this crate.
Not all of the supported encodings are supported to serialize and deserialize into. Some, like hjson only allow deserialization of encoded data but are not able to serialize back into the original representation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Json
JavaScript Object Notation
Yaml
Yet Another Markup Language
Toml
TOML configuration format
Json5
ES5 JSON
Csv
Comma separated values
QueryString
URL query string
Xml
Extensible Markup Language
Text
Plaintext document
Gron
Gron
Hcl
HCL
Implementations
sourceimpl Encoding
impl Encoding
sourcepub fn from_path<P>(path: P) -> Option<Encoding> where
P: AsRef<Path>,
pub fn from_path<P>(path: P) -> Option<Encoding> where
P: AsRef<Path>,
Creates an Encoding from a path by looking at the file extension.
Returns None if the extension is absent or if the extension does not match any of the
supported encodings.
sourcepub fn from_first_line(line: &str) -> Option<Encoding>
pub fn from_first_line(line: &str) -> Option<Encoding>
Tries to detect the Encoding by looking at the first line of the input.
Returns None if the encoding cannot be detected from the first line.