#[non_exhaustive]
pub enum Error {
Message(String),
UnsupportedEncoding(Encoding),
ParseError(ParseError),
Jq(Error),
Io(Error),
GlobPatternError {
pattern: String,
source: PatternError,
},
RequestError(Error),
Serde(Box<dyn StdError + Send + Sync>),
}Expand description
The error returned by all fallible operations within this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Message(String)
Represents a generic error message.
UnsupportedEncoding(Encoding)
Represents errors of operations that are not supported by a certain encoding.
ParseError(ParseError)
Error emitted by parsers from this crate.
Jq(Error)
Represents an error emitted while invoking jq.
Io(Error)
Represents generic IO errors.
GlobPatternError
Represents an invalid glob pattern.
RequestError(Error)
Represents an error fetching a remote data source.
Serde(Box<dyn StdError + Send + Sync>)
Represents errors emitted by serializers and deserializers.