Struct dts_core::ser::SerializeOptions
source · [−]pub struct SerializeOptions {
pub compact: bool,
pub newline: bool,
pub keys_as_csv_headers: bool,
pub csv_delimiter: Option<u8>,
pub text_join_separator: Option<String>,
}Expand description
Options for the Serializer. The options are context specific and may only be honored when
serializing into a certain Encoding.
Fields
compact: boolEmit output data in a compact format. This will disable pretty printing for encodings that support it.
newline: boolAppend a trailing newline to the serialized data.
keys_as_csv_headers: boolWhen the input is an array of objects and the output encoding is CSV, the field names of the first object will be used as CSV headers. Field values of all following objects will be matched to the right CSV column based on their key. Missing fields produce empty columns while excess fields are ignored.
csv_delimiter: Option<u8>Optional custom delimiter for CSV output.
text_join_separator: Option<String>Optional seprator to join text output with.
Implementations